@@ -47,12 +47,16 @@ static volatile pixman_bool_t have_vmx = TRUE;
 static pixman_bool_t
 pixman_have_vmx (void)
 {
-    if(!initialized) {
-        size_t length = sizeof(have_vmx);
-        int error =
-            sysctlbyname("hw.optional.altivec", &have_vmx, &length, NULL, 0);
-        if(error) have_vmx = FALSE;
-        initialized = TRUE;
+    if (!initialized)
+    {
+	size_t length = sizeof(have_vmx);
+	int error =
+	    sysctlbyname ("hw.optional.altivec", &have_vmx, &length, NULL, 0);
+
+	if (error)
+	    have_vmx = FALSE;
+
+	initialized = TRUE;
     }
     return have_vmx;
 }
@@ -69,39 +73,47 @@ pixman_have_vmx (void)
 static pixman_bool_t
 pixman_have_vmx (void)
 {
-    if (!initialized) {
+    if (!initialized)
+    {
 	char fname[64];
 	unsigned long buf[64];
 	ssize_t count = 0;
 	pid_t pid;
 	int fd, i;
 
-	pid = getpid();
-	snprintf(fname, sizeof(fname)-1, "/proc/%d/auxv", pid);
+	pid = getpid ();
+	snprintf (fname, sizeof(fname) - 1, "/proc/%d/auxv", pid);
 
-	fd = open(fname, O_RDONLY);
-	if (fd >= 0) {
-	    for (i = 0; i <= (count / sizeof(unsigned long)); i += 2) {
+	fd = open (fname, O_RDONLY);
+	if (fd >= 0)
+	{
+	    for (i = 0; i <= (count / sizeof(unsigned long)); i += 2)
+	    {
 		/* Read more if buf is empty... */
-		if (i == (count / sizeof(unsigned long))) {
-		    count = read(fd, buf, sizeof(buf));
+		if (i == (count / sizeof(unsigned long)))
+		{
+		    count = read (fd, buf, sizeof(buf));
 		    if (count <= 0)
 			break;
 		    i = 0;
 		}
 
-		if (buf[i] == AT_HWCAP) {
-		    have_vmx = !!(buf[i+1] & PPC_FEATURE_HAS_ALTIVEC);
+		if (buf[i] == AT_HWCAP)
+		{
+		    have_vmx = !!(buf[i + 1] & PPC_FEATURE_HAS_ALTIVEC);
 		    initialized = TRUE;
 		    break;
-		} else if (buf[i] == AT_NULL) {
+		}
+		else if (buf[i] == AT_NULL)
+		{
 		    break;
 		}
 	    }
-	    close(fd);
+	    close (fd);
 	}
     }
-    if (!initialized) {
+    if (!initialized)
+    {
 	/* Something went wrong. Assume 'no' rather than playing
 	   fragile tricks with catching SIGILL. */
 	have_vmx = FALSE;
@@ -110,35 +122,45 @@ pixman_have_vmx (void)
 
     return have_vmx;
 }
+
 #else /* !__APPLE__ && !__linux__ */
 #include <signal.h>
 #include <setjmp.h>
 
 static jmp_buf jump_env;
 
-static void vmx_test(int sig, siginfo_t *si, void *unused) {
+static void
+vmx_test (int        sig,
+	  siginfo_t *si,
+	  void *     unused)
+{
     longjmp (jump_env, 1);
 }
 
 static pixman_bool_t
-pixman_have_vmx (void) {
+pixman_have_vmx (void)
+{
     struct sigaction sa, osa;
     int jmp_result;
-    if (!initialized) {
-        sa.sa_flags = SA_SIGINFO;
-        sigemptyset(&sa.sa_mask);
-        sa.sa_sigaction = vmx_test;
-        sigaction(SIGILL, &sa, &osa);
+
+    if (!initialized)
+    {
+	sa.sa_flags = SA_SIGINFO;
+	sigemptyset (&sa.sa_mask);
+	sa.sa_sigaction = vmx_test;
+	sigaction (SIGILL, &sa, &osa);
 	jmp_result = setjmp (jump_env);
-	if (jmp_result == 0) {
+	if (jmp_result == 0)
+	{
 	    asm volatile ( "vor 0, 0, 0" );
 	}
-        sigaction(SIGILL, &osa, NULL);
+	sigaction (SIGILL, &osa, NULL);
 	have_vmx = (jmp_result == 0);
-        initialized = TRUE;
+	initialized = TRUE;
     }
     return have_vmx;
 }
+
 #endif /* __APPLE__ */
 #endif /* USE_VMX */
 
@@ -147,7 +169,7 @@ pixman_have_vmx (void) {
 #if defined(_MSC_VER)
 
 #if defined(USE_ARM_SIMD)
-extern int pixman_msvc_try_arm_simd_op();
+extern int pixman_msvc_try_arm_simd_op ();
 
 pixman_bool_t
 pixman_have_arm_simd (void)
@@ -155,22 +177,24 @@ pixman_have_arm_simd (void)
     static pixman_bool_t initialized = FALSE;
     static pixman_bool_t have_arm_simd = FALSE;
 
-    if (!initialized) {
-        __try {
-            pixman_msvc_try_arm_simd_op();
-            have_arm_simd = TRUE;
-        } __except(GetExceptionCode() == EXCEPTION_ILLEGAL_INSTRUCTION) {
-            have_arm_simd = FALSE;
-        }
+    if (!initialized)
+    {
+	__try {
+	    pixman_msvc_try_arm_simd_op ();
+	    have_arm_simd = TRUE;
+	} __except (GetExceptionCode () == EXCEPTION_ILLEGAL_INSTRUCTION) {
+	    have_arm_simd = FALSE;
+	}
 	initialized = TRUE;
     }
 
     return have_arm_simd;
 }
+
 #endif /* USE_ARM_SIMD */
 
 #if defined(USE_ARM_NEON)
-extern int pixman_msvc_try_arm_neon_op();
+extern int pixman_msvc_try_arm_neon_op ();
 
 pixman_bool_t
 pixman_have_arm_neon (void)
@@ -178,18 +202,23 @@ pixman_have_arm_neon (void)
     static pixman_bool_t initialized = FALSE;
     static pixman_bool_t have_arm_neon = FALSE;
 
-    if (!initialized) {
-        __try {
-            pixman_msvc_try_arm_neon_op();
-            have_arm_neon = TRUE;
-        } __except(GetExceptionCode() == EXCEPTION_ILLEGAL_INSTRUCTION) {
-            have_arm_neon = FALSE;
-        }
+    if (!initialized)
+    {
+	__try
+	{
+	    pixman_msvc_try_arm_neon_op ();
+	    have_arm_neon = TRUE;
+	}
+	__except (GetExceptionCode () == EXCEPTION_ILLEGAL_INSTRUCTION)
+	{
+	    have_arm_neon = FALSE;
+	}
 	initialized = TRUE;
     }
 
     return have_arm_neon;
 }
+
 #endif /* USE_ARM_NEON */
 
 #else /* linux ELF */
@@ -211,40 +240,49 @@ static pixman_bool_t arm_has_iwmmxt = FALSE;
 static pixman_bool_t arm_tests_initialized = FALSE;
 
 static void
-pixman_arm_read_auxv() {
+pixman_arm_read_auxv ()
+{
     int fd;
     Elf32_auxv_t aux;
 
-    fd = open("/proc/self/auxv", O_RDONLY);
-    if (fd >= 0) {
-        while (read(fd, &aux, sizeof(Elf32_auxv_t)) == sizeof(Elf32_auxv_t)) {
-            if (aux.a_type == AT_HWCAP) {
+    fd = open ("/proc/self/auxv", O_RDONLY);
+    if (fd >= 0)
+    {
+	while (read (fd, &aux, sizeof(Elf32_auxv_t)) == sizeof(Elf32_auxv_t))
+	{
+	    if (aux.a_type == AT_HWCAP)
+	    {
 		uint32_t hwcap = aux.a_un.a_val;
-		if (getenv("ARM_FORCE_HWCAP"))
-		    hwcap = strtoul(getenv("ARM_FORCE_HWCAP"), NULL, 0);
+		if (getenv ("ARM_FORCE_HWCAP"))
+		    hwcap = strtoul (getenv ("ARM_FORCE_HWCAP"), NULL, 0);
 		// hardcode these values to avoid depending on specific versions
 		// of the hwcap header, e.g. HWCAP_NEON
 		arm_has_vfp = (hwcap & 64) != 0;
 		arm_has_iwmmxt = (hwcap & 512) != 0;
 		// this flag is only present on kernel 2.6.29
 		arm_has_neon = (hwcap & 4096) != 0;
-            } else if (aux.a_type == AT_PLATFORM) {
+	    }
+	    else if (aux.a_type == AT_PLATFORM)
+	    {
 		const char *plat = (const char*) aux.a_un.a_val;
-		if (getenv("ARM_FORCE_PLATFORM"))
-		    plat = getenv("ARM_FORCE_PLATFORM");
-		if (strncmp(plat, "v7l", 3) == 0) {
+		if (getenv ("ARM_FORCE_PLATFORM"))
+		    plat = getenv ("ARM_FORCE_PLATFORM");
+		if (strncmp (plat, "v7l", 3) == 0)
+		{
 		    arm_has_v7 = TRUE;
 		    arm_has_v6 = TRUE;
-		} else if (strncmp(plat, "v6l", 3) == 0) {
+		}
+		else if (strncmp (plat, "v6l", 3) == 0)
+		{
 		    arm_has_v6 = TRUE;
 		}
-            }
-        }
-        close (fd);
+	    }
+	}
+	close (fd);
 
 	// if we don't have 2.6.29, we have to do this hack; set
 	// the env var to trust HWCAP.
-	if (!getenv("ARM_TRUST_HWCAP") && arm_has_v7)
+	if (!getenv ("ARM_TRUST_HWCAP") && arm_has_v7)
 	    arm_has_neon = TRUE;
     }
 
@@ -256,10 +294,11 @@ pixman_bool_t
 pixman_have_arm_simd (void)
 {
     if (!arm_tests_initialized)
-	pixman_arm_read_auxv();
+	pixman_arm_read_auxv ();
 
     return arm_has_v6;
 }
+
 #endif /* USE_ARM_SIMD */
 
 #if defined(USE_ARM_NEON)
@@ -267,10 +306,11 @@ pixman_bool_t
 pixman_have_arm_neon (void)
 {
     if (!arm_tests_initialized)
-	pixman_arm_read_auxv();
+	pixman_arm_read_auxv ();
 
     return arm_has_neon;
 }
+
 #endif /* USE_ARM_NEON */
 
 #endif /* linux */
@@ -289,31 +329,36 @@ pixman_have_arm_neon (void)
 #include <sys/auxv.h>
 #endif
 
-enum CPUFeatures {
-    NoFeatures = 0,
+typedef enum
+{
+    NO_FEATURES = 0,
     MMX = 0x1,
-    MMX_Extensions = 0x2,
+    MMX_EXTENSIONS = 0x2,
     SSE = 0x6,
     SSE2 = 0x8,
     CMOV = 0x10
-};
+} cpu_features_t;
 
-static unsigned int detectCPUFeatures(void) {
+
+static unsigned int
+detect_cpu_features (void)
+{
     unsigned int features = 0;
     unsigned int result = 0;
 
 #ifdef HAVE_GETISAX
-    if (getisax(&result, 1)) {
-        if (result & AV_386_CMOV)
-            features |= CMOV;
-        if (result & AV_386_MMX)
-            features |= MMX;
-        if (result & AV_386_AMD_MMX)
-            features |= MMX_Extensions;
-        if (result & AV_386_SSE)
-            features |= SSE;
-        if (result & AV_386_SSE2)
-            features |= SSE2;
+    if (getisax (&result, 1))
+    {
+	if (result & AV_386_CMOV)
+	    features |= CMOV;
+	if (result & AV_386_MMX)
+	    features |= MMX;
+	if (result & AV_386_AMD_MMX)
+	    features |= MMX_EXTENSIONS;
+	if (result & AV_386_SSE)
+	    features |= SSE;
+	if (result & AV_386_SSE2)
+	    features |= SSE2;
     }
 #else
     char vendor[13];
@@ -333,128 +378,130 @@ static unsigned int detectCPUFeatures(void) {
      * original values when we access the output operands.
      */
     __asm__ (
-	"pushf\n"
-	"pop %%eax\n"
-	"mov %%eax, %%ecx\n"
-	"xor $0x00200000, %%eax\n"
-	"push %%eax\n"
-	"popf\n"
-	"pushf\n"
-	"pop %%eax\n"
-	"mov $0x0, %%edx\n"
-	"xor %%ecx, %%eax\n"
-	"jz 1f\n"
-	
-	"mov $0x00000000, %%eax\n"
-	"push %%ebx\n"
-	"cpuid\n"
-	"mov %%ebx, %%eax\n"
-	"pop %%ebx\n"
-	"mov %%eax, %1\n"
-	"mov %%edx, %2\n"
-	"mov %%ecx, %3\n"
-	"mov $0x00000001, %%eax\n"
-	"push %%ebx\n"
-	"cpuid\n"
-	"pop %%ebx\n"
-	"1:\n"
-	"mov %%edx, %0\n"
+        "pushf\n"
+        "pop %%eax\n"
+        "mov %%eax, %%ecx\n"
+        "xor $0x00200000, %%eax\n"
+        "push %%eax\n"
+        "popf\n"
+        "pushf\n"
+        "pop %%eax\n"
+        "mov $0x0, %%edx\n"
+        "xor %%ecx, %%eax\n"
+        "jz 1f\n"
+
+        "mov $0x00000000, %%eax\n"
+        "push %%ebx\n"
+        "cpuid\n"
+        "mov %%ebx, %%eax\n"
+        "pop %%ebx\n"
+        "mov %%eax, %1\n"
+        "mov %%edx, %2\n"
+        "mov %%ecx, %3\n"
+        "mov $0x00000001, %%eax\n"
+        "push %%ebx\n"
+        "cpuid\n"
+        "pop %%ebx\n"
+        "1:\n"
+        "mov %%edx, %0\n"
 	: "=r" (result),
-	  "=m" (vendor[0]),
-	  "=m" (vendor[4]),
-	  "=m" (vendor[8])
+        "=m" (vendor[0]),
+        "=m" (vendor[4]),
+        "=m" (vendor[8])
 	:
 	: "%eax", "%ecx", "%edx"
         );
-    
+
 #elif defined (_MSC_VER)
 
     _asm {
-      pushfd
-      pop eax
-      mov ecx, eax
-      xor eax, 00200000h
-      push eax
-      popfd
-      pushfd
-      pop eax
-      mov edx, 0
-      xor eax, ecx
-      jz nocpuid
+	pushfd
+	pop eax
+	mov ecx, eax
+	xor eax, 00200000h
+	push eax
+	popfd
+	pushfd
+	pop eax
+	mov edx, 0
+	xor eax, ecx
+	jz nocpuid
 
-      mov eax, 0
-      push ebx
-      cpuid
-      mov eax, ebx
-      pop ebx
-      mov vendor0, eax
-      mov vendor1, edx
-      mov vendor2, ecx
-      mov eax, 1
-      push ebx
-      cpuid
-      pop ebx
+	mov eax, 0
+	push ebx
+	cpuid
+	mov eax, ebx
+	pop ebx
+	mov vendor0, eax
+	mov vendor1, edx
+	mov vendor2, ecx
+	mov eax, 1
+	push ebx
+	cpuid
+	pop ebx
     nocpuid:
-      mov result, edx
+	mov result, edx
     }
-    memmove (vendor+0, &vendor0, 4);
-    memmove (vendor+4, &vendor1, 4);
-    memmove (vendor+8, &vendor2, 4);
+    memmove (vendor + 0, &vendor0, 4);
+    memmove (vendor + 4, &vendor1, 4);
+    memmove (vendor + 8, &vendor2, 4);
 
 #else
 #   error unsupported compiler
 #endif
 
     features = 0;
-    if (result) {
-        /* result now contains the standard feature bits */
-        if (result & (1 << 15))
-            features |= CMOV;
-        if (result & (1 << 23))
-            features |= MMX;
-        if (result & (1 << 25))
-            features |= SSE;
-        if (result & (1 << 26))
-            features |= SSE2;
-        if ((features & MMX) && !(features & SSE) &&
-            (strcmp(vendor, "AuthenticAMD") == 0 ||
-             strcmp(vendor, "Geode by NSC") == 0)) {
-            /* check for AMD MMX extensions */
+    if (result)
+    {
+	/* result now contains the standard feature bits */
+	if (result & (1 << 15))
+	    features |= CMOV;
+	if (result & (1 << 23))
+	    features |= MMX;
+	if (result & (1 << 25))
+	    features |= SSE;
+	if (result & (1 << 26))
+	    features |= SSE2;
+	if ((features & MMX) && !(features & SSE) &&
+	    (strcmp (vendor, "AuthenticAMD") == 0 ||
+	     strcmp (vendor, "Geode by NSC") == 0))
+	{
+	    /* check for AMD MMX extensions */
 #ifdef __GNUC__
-            __asm__(
-		"	push %%ebx\n"
-		"	mov $0x80000000, %%eax\n"
-		"	cpuid\n"
-		"	xor %%edx, %%edx\n"
-		"	cmp $0x1, %%eax\n"
-		"	jge 2f\n"
-		"	mov $0x80000001, %%eax\n"
-		"	cpuid\n"
-		"2:\n"
-		"	pop %%ebx\n"
-		"	mov %%edx, %0\n"
+	    __asm__ (
+	        "	push %%ebx\n"
+	        "	mov $0x80000000, %%eax\n"
+	        "	cpuid\n"
+	        "	xor %%edx, %%edx\n"
+	        "	cmp $0x1, %%eax\n"
+	        "	jge 2f\n"
+	        "	mov $0x80000001, %%eax\n"
+	        "	cpuid\n"
+	        "2:\n"
+	        "	pop %%ebx\n"
+	        "	mov %%edx, %0\n"
 		: "=r" (result)
 		:
 		: "%eax", "%ecx", "%edx"
-                );
+	        );
 #elif defined _MSC_VER
-            _asm {
-              push ebx
-              mov eax, 80000000h
-              cpuid
-              xor edx, edx
-              cmp eax, 1
-              jge notamd
-              mov eax, 80000001h
-              cpuid
-            notamd:
-              pop ebx
-              mov result, edx
-            }
+	    _asm {
+		push ebx
+		mov eax, 80000000h
+		cpuid
+		xor edx, edx
+		cmp eax, 1
+		jge notamd
+		mov eax, 80000001h
+		cpuid
+	    notamd:
+		pop ebx
+		mov result, edx
+	    }
 #endif
-            if (result & (1<<22))
-                features |= MMX_Extensions;
-        }
+	    if (result & (1 << 22))
+		features |= MMX_EXTENSIONS;
+	}
     }
 #endif /* HAVE_GETISAX */
 
@@ -469,9 +516,9 @@ pixman_have_mmx (void)
 
     if (!initialized)
     {
-        unsigned int features = detectCPUFeatures();
-	mmx_present = (features & (MMX|MMX_Extensions)) == (MMX|MMX_Extensions);
-        initialized = TRUE;
+	unsigned int features = detect_cpu_features ();
+	mmx_present = (features & (MMX | MMX_EXTENSIONS)) == (MMX | MMX_EXTENSIONS);
+	initialized = TRUE;
     }
 
     return mmx_present;
@@ -486,13 +533,14 @@ pixman_have_sse2 (void)
 
     if (!initialized)
     {
-        unsigned int features = detectCPUFeatures();
-        sse2_present = (features & (MMX|MMX_Extensions|SSE|SSE2)) == (MMX|MMX_Extensions|SSE|SSE2);
-        initialized = TRUE;
+	unsigned int features = detect_cpu_features ();
+	sse2_present = (features & (MMX | MMX_EXTENSIONS | SSE | SSE2)) == (MMX | MMX_EXTENSIONS | SSE | SSE2);
+	initialized = TRUE;
     }
 
     return sse2_present;
 }
+
 #endif
 
 #else /* __amd64__ */
@@ -510,25 +558,26 @@ _pixman_choose_implementation (void)
 {
 #ifdef USE_SSE2
     if (pixman_have_sse2 ())
-	return _pixman_implementation_create_sse2 (NULL);
+	return _pixman_implementation_create_sse2 ();
 #endif
 #ifdef USE_MMX
-    if (pixman_have_mmx())
-	return _pixman_implementation_create_mmx (NULL);
+    if (pixman_have_mmx ())
+	return _pixman_implementation_create_mmx ();
 #endif
 
 #ifdef USE_ARM_NEON
-    if (pixman_have_arm_neon())
-	return _pixman_implementation_create_arm_neon (NULL);
+    if (pixman_have_arm_neon ())
+	return _pixman_implementation_create_arm_neon ();
 #endif
 #ifdef USE_ARM_SIMD
-    if (pixman_have_arm_simd())
-	return _pixman_implementation_create_arm_simd (NULL);
+    if (pixman_have_arm_simd ())
+	return _pixman_implementation_create_arm_simd ();
 #endif
 #ifdef USE_VMX
-    if (pixman_have_vmx())
-	return _pixman_implementation_create_vmx (NULL);
+    if (pixman_have_vmx ())
+	return _pixman_implementation_create_vmx ();
 #endif
-    
-    return _pixman_implementation_create_fast_path (NULL);
+
+    return _pixman_implementation_create_fast_path ();
 }
+
